//
//  DiceGL.h
//  DiceView
//
//  Created by kunii on 10/03/29.
//  Copyright 2010 Apple Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <QuartzCore/QuartzCore.h>
#import <OpenGLES/EAGLDrawable.h>
#import <OpenGLES/EAGL.h>
#import <OpenGLES/ES1/gl.h>

@interface DiceGL : NSObject {
	UIImage*		defaultImages[6];		//	初期画像（サイコロ）6面分
	GLuint			texture[6];				//	テクスチャ6面分
	int				maxIndex;				//	photos count と同じ値、
	NSMutableArray*	photos;					//	メンバー用写真を保持する。

	double			angle;					//	サイコロの回転度数
	int				movingPhase;			//	アニメーションの段階
	int				curtImageIndex[2];		//	現在の前2面に使われている画像のインディックスを記憶

	//	以下は movingPhase_Idle 時で有効
	double			xAxisRotateAngle;		//	x軸回転角
	double			xAxisRotateDeltaAngle;	//	x軸回転角スピード調整用
#if THROW_ANIMATION
	int				marginIndex;			//	停止画像番号よりこの数分手前から、じらし用のゆっくりした回転に変化させる。
	double			stopAngle;				//	停止角（行き過ぎる分も含めている）
	double			adjustedFinalAngle;		//	停止角（確定用）
	double			deltaAngle;				//	速度
	double			deltaDeltaAngle;		//	加速度
	int				deltaTime;				//	回転経過時間。drawは1/60秒ごとに呼ばれるので（EAGLView.m参照）この値が60で1秒経過ということになる。
	double			rotationDirection;		//	画面上の回転方向（-1か1）
#endif
}

//	描画
-(void)draw;
//	サイコロを振る
-(void)throwDice:(double)inDelta;
//	写真設定
-(void)setImages:(UIImage**)images max:(int)max;
@end

enum {
	movingPhase_Idle,		//	オーナーが決まっていなくてアイドル状態
	movingPhase_Rotate,		//	回転中
	movingPhase_Turn,		//	行き過ぎたので戻っている最中
	movingPhase_Stop		//	オーナーを表示中
};